@@ -27,7 +27,7 @@
 #include <vector>
 
 // version of Gmail KCheckGmail works with
-static const QString gGMailVersion = "38cb0ca268823b81";
+static const QString gGMailVersion = "51a4dc5081b98a29,cb6e092c102a1489,7";
 
 /**
 @author Matthew Wlazlo
@@ -66,7 +66,7 @@ public:
 		QString replyId;
 		bool isNew;
 		unsigned int unknown1;
-		QString date;
+		QString date_short;
 		QString senders;
 		QString chevron;
 		QString subject;
@@ -74,6 +74,8 @@ public:
 		QString labels;
 		QString attachments;
 		QString msgId;
+		unsigned int unknown2;
+		QString date_long;
 		unsigned int unknown3;
 		bool isNull; 
 	} Thread;
